/**
 * Copyright (C) 2008 - Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI OW2 Layer
 *
 * This library is developed inside the OW2 Consortium,
 * http://www.ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JRequestInfoInvocationHandler.java 1888 2008-07-01 12:44:30Z amrania $
 * --------------------------------------------------------------------------
 */
package org.ow2.carol.rmi.jrmp.interceptor.impl.legacy;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;

import org.ow2.carol.rmi.interceptor.api.JRequestInfo;
import org.ow2.carol.rmi.interceptor.spi.JServiceContext;

/**
 * Handle invocations on a request info designed for Carol 3.x.
 * @author Loris Bouzonnet
 */
class JRequestInfoInvocationHandler implements
        InvocationHandler {

    /**
     * A request info designed for Carol 3.x.
     */
    private final JRequestInfo jRequestInfo;

    /**
     * Construct a new invocation handler for request info.
     * @param jRequestInfo a request info designed for Carol 3.x
     */
    public JRequestInfoInvocationHandler(
            final JRequestInfo jRequestInfo) {
        this.jRequestInfo = jRequestInfo;
    }

    @SuppressWarnings("deprecation")
    public Object invoke(final Object proxy, final Method legacyMethod, final Object[] args)
            throws Throwable {
        Class<?>[] typeArgs = legacyMethod.getParameterTypes();
        if(args != null
                && args.length == 1
                && (args[0] instanceof org.objectweb.carol.rmi.jrmp.interceptor.JServiceContext)) {
            typeArgs = new Class<?>[] {JServiceContext.class};
        }
        Method method = jRequestInfo.getClass().getMethod(convertMethodName(legacyMethod.getName()), typeArgs);
        return method.invoke(jRequestInfo, args);
    }


    private String convertMethodName(final String methodName) {
    	String result = "";
        int length = methodName.length();
        int index = 0;
        while(index != length) {
            char c = methodName.charAt(index);
            if(c == '_') {
            	index ++;
                result = result.concat(Character.toString(methodName.charAt(index)).toUpperCase());
            } else {
            	result = result.concat(Character.toString(c));
            }
            index++;
        }
        return result;
    }

}
